/************************************************************************************************************
 * (c) Triple-S GmbH 2012
 ************************************************************************************************************/
/*****************************************************************************
*   $Logfile: /SOURCE/Scheduler.c $
*   $Revision: 1 $
*   $Author: Hbl $
*   $Date: 2012.11.28 13:13:13 $
*
*    Project:                   TEST
*
*    Content:                   Implementierung der Funktionen fr das Modul Scheduler
*
*
*    Author(s):                 JH: Josef Hbl
*
*****************************************************************************/

/*****************************************************************************
*
* CHANGE LOG:
*
* Date     Name Change description
* -----------------------------------------------------------------
*
*****************************************************************************/

/*****************************************************************************
*    Includes
*****************************************************************************/
#include "Project_Defines.h"
#include "Globals.h"

#ifdef SCHEDULER

#define SCHEDULER_C
#include "Scheduler.h"
#undef SCHEDULER_C

/*****************************************************************************
*    Local Defines
*****************************************************************************/
#define BASIC_TIMER_x2        (0x01)
#define BASIC_TIMER_x4        (0x02)
#define BASIC_TIMER_x8        (0x04)
#define BASIC_TIMER_x16       (0x08)
#define BASIC_TIMER_x32       (0x10)
#define BASIC_TIMER_x64       (0x20)
#define BASIC_TIMER_x128      (0x40)
#define BASIC_TIMER_x256      (0x80)

/*---- Internal Macros -----------------------------------------------------*/
/* MISRA[4:3453]: Used for better readability */
#define TIME_SLICE_CALL( func ) ((func)())

/*****************************************************************************
*    Type definitions
*****************************************************************************/

/*****************************************************************************
*    Global variables
*****************************************************************************/

/*****************************************************************************
*    Local variables
*****************************************************************************/

/*****************************************************************************
*    Local Prototypes
*****************************************************************************/

static void TimerTick_BASEx1( void );
static void TimerTick_BASEx5( void );
static void TimerTick_BASEx25( void );

/*****************************************************************************
*   Functions
*****************************************************************************/

/*****************************************************************************
*
* Name          Scheduler_TimeSlice_BASE
*
* Author        Josef Hbl
*
* Remark        implements entry function cyclically called by OS
*
*****************************************************************************/

void Scheduler_TimeSlice_BASE(void)
{
	static uint08 u08_GenericTimerCounter_BASEx5=1;
	static uint08 u08_GenericTimerCounter_BASEx25=1;

	BEGIN_TIMESLICE()


	/* 5ms : 5x1x1 ms */
	Can_MainFunction_Write();
	Can_MainFunction_Read();
	FrIf_MainFunction_0();
	LinIf_MainFunction();
	CanNm_MainFunction();
	FrNm_MainFunction_0();
	CanSM_MainFunction();
	FrSM_MainFunction_0();
	FrTp_MainFunction();
	CanTp_MainFunction();
	Com_MainFunctionRx();
	Com_MainFunctionRouteSignals();
	Com_MainFunctionTx();
	KvProxy_MainFunction();
	IoHwAbEx_MainFunction();

	TimerTick_BASEx1();


	/* check for TimerTick_BASEx5 */
	if (5 == u08_GenericTimerCounter_BASEx5)
	{
		TimerTick_BASEx5();
		u08_GenericTimerCounter_BASEx5 = 1;
	}
	else
	{
		u08_GenericTimerCounter_BASEx5++;
	}


	/* check for TimerTick_BASEx25 */
	if (25 == u08_GenericTimerCounter_BASEx25)
	{
		/* 125ms : 5x25x1 ms */
		ComCtrl_CarCfg_Run();

		TimerTick_BASEx25();
		u08_GenericTimerCounter_BASEx25 = 1;
	}
	else
	{
		u08_GenericTimerCounter_BASEx25++;
	}

	END_TIMESLICE()

}//void Scheduler_TimeSlice_BASE(void)


/*****************************************************************************
*
* Name          TimerTick_BASEx1
*
* Author        Josef Hbl
*
* Remark        implements a simulated timer tick
*
*****************************************************************************/

static void TimerTick_BASEx1( void )
{
	static uint08 u08_TimerCounter_BASEx1 = 0;

	if ((BASIC_TIMER_x2 & u08_TimerCounter_BASEx1) != 0)
	{
		/* 10ms : 5x1x2 ms */
		LinSM_MainFunction();
		Xcp_MainFunction();
		Can_MainFunction_Mode();
		Fee_MainFunction();
		NvM_MainFunction();
		CddTpms_MainFunction();
		EcuM_MainFunction();
		Run_SenActExteriorLight_Sensor();
		Run_SenActLocking_Sensor();
		Run_SenActImmo_Sensor();
		Run_SenActVMM_Sensor();
		Run_FlashMgr_Step();
		Run_BrkLiMgr_Step();
		Run_SftyMgrForLockgCen_Step();
		Run_ElEgyMgr_Step();
		Run_PwrSplyMgr_Step();
		Run_PtIninMgr_Step();
		Run_StrtMgr_Step();
		Run_ImobMgr_Step();
		Run_ImobEngMgr1_Step();
		Run_ImobEngMgr2_Step();
		Run_ImobEngMgr3_Step();
		Run_KeyMgr_Step();
		Run_RemInfo_Step();
		Run_ImobSteerLockMgr_Step();
		Run_CryptoMgr_Step();
		Run_SenActExteriorLight_Actuator();
		Run_SenActImmo_Actuator();
		Run_SenActLocking_Actuator();
		Run_SenActVMM_Actuator();
		Run_Comfort_Step();
		Run_ComNet_Step();
		Run_CtrlOut_Step();
		Run_DecodeEval_Step();
		Run_Feedback_Step();
		Run_KeySearch_Step();
		Run_VehModMngtSync_Step();
		Run_UsgModMgrSafe_Step();
		Run_PwrSplyMgrSafe_Step();
		Run_CarModMgrSafe_Step();
		Run_CarModMgr_Step();
		Run_UsgModMgr_Step();
		Run_SftyMgrForSteerLockMgr_Step();
		Run_TirePMon_Cyclic_Prolog();
		Run_TirePMon_Cyclic();
		Run_TirePMon_Cyclic_Epilog();
	}
	else if ((BASIC_TIMER_x4 & u08_TimerCounter_BASEx1) != 0)
	{
		/* 20ms : 5x1x4 ms */
		Run_SenActInteriorLight_Actuator();
		Run_SenActInteriorLight_Sensor();
		Run_SenActSoundSignaling_Sensor();
		Run_SenActSoundSignaling_Actuator();
		Run_HornMgr_Step();
		Run_ComArbn_Step();
		Run_Hdlmp_Step();
		Run_HdlmpSafe_Step();
		Run_DynLoadCtrl_Step();
	}
	else if ((BASIC_TIMER_x8 & u08_TimerCounter_BASEx1) != 0)
	{
		/* 40ms : 5x1x8 ms */
		Run_Rngbd_Step();
		Run_IntrLiMgr_Step();
	}
	else
	{
		/*to avoid misra warning*/
	}

    /* check for counter reset */
    if (0xFF == u08_TimerCounter_BASEx1)
    {
        u08_TimerCounter_BASEx1 = 0;
    }
    else
    {
        u08_TimerCounter_BASEx1++;
    }
}//TimerTick_BASEx1

/*****************************************************************************
*
* Name          TimerTick_BASEx5
*
* Author        Josef Hbl
*
* Remark        implements a simulated timer tick
*
*****************************************************************************/

static void TimerTick_BASEx5( void )
{
	static uint08 u08_TimerCounter_BASEx5 = 0;

	if ((BASIC_TIMER_x2 & u08_TimerCounter_BASEx5) != 0)
	{
		/* 50ms : 5x5x2 ms */
		ComCtrl_LinHandler_Run();
		ComCtrl_VfcHandler_Run();
		Run_SenActTheftProtection_Sensor();
		Run_AlrmMgr_Step();
		Run_SnsrAdptrSimpleAlrm_Step();
		Run_SnsrAdptrCmplxAlrm_Step();
		Run_WiprWshrMgrSafe_Step();
		Run_WiprWshrMgr_Step();
		Run_WindscreenCleanerCtrl_Step();
		Run_DefrstCtrlMgr_Step();
		Run_ProfMgr_Step();
		Run_HeadRest_Step();
		Run_ExtrLiMgr_Step();
		Run_PwrAndEgyBalMgr_Step();
		Run_PanicAlrmMgr_Step();
		Run_SenActVisibility_Actuator();
		Run_SenActTheftProtection_Actuator();
		Run_LoBeamSafe_Step();
		Run_PosLiReSafe_Step();
		Run_SenActVisibility_Sensor();
	}
	else if ((BASIC_TIMER_x4 & u08_TimerCounter_BASEx5) != 0)
	{
		/* 100ms : 5x5x4 ms */
		ComCtrl_TimeoutCheck_Run();
		Run_SenActLowVoltEngyMngt_Sensor();
		Run_SenActDriverInformation_Sensor();
		Run_PasAlrmCtrl_Step();
		Run_SpprtBattMgr_Step();
		Run_PwrSplyUCtrl_Step();
		Run_DiagCtrl_Step();
		Run_FCCCEM_Step();
		Run_MissComSignalsCEM_Step();
		Run_ModCtrl_Step();
		Run_NvCtrl_Step();
		Run_RealTi_Step();
		Run_TpmsProxy_Step();
		Run_RxDataGlbForDiagcTroCodCEM_Step();
		Run_TiMgr_Step();
		Run_SunRoofAndCurtSecCtrlr_Step();
		Run_PrsnlCfgCmn_Step();
		Run_GlbWinCtrl_Step();
		Run_NvArbn_Step();
		Run_ModArbn_Step();
		Run_UsrIntxcnMgr_Step();
		Run_KeyWarnMgr_Step();
		Run_ImobVehRemMgr_Step();
		Run_CryptoMgrSlow_Step();
		Run_SysSftyMngtByPwrSply_Step();
		Run_SwtStsAtBody_Step();
		Run_DrvrEngmtLvlMgr_Step();
		Run_NetMgrForAlrm_Step();
		Run_AmbTMgr_Step();
		Run_SenActDriverInformation_Diag();
		Run_SenActDriverInformation_Actuator();
		Run_SenActExteriorLight_Diag();
		Run_SenActImmo_Diag();
		Run_SenActInteriorLight_Diag();
		Run_SenActVisibility_Diag();
		Run_SenActVMM_Diag();
		Run_SenActTheftProtection_Diag();
		Run_SenActSoundSignaling_Diag();
		Run_SenActLowVoltEngyMngt_Actuator();
		Run_SenActLowVoltEngyMngt_Diag();
		Run_SenActLocking_Diag();
		Run_CarCfg_Step();
		Run_CmptmtClngMgr_Step();
		Run_HeatdSteerWhlMaiCtrl_Step();
		Run_SunSnsrIf2_Step();
		Run_DiagcOfSlaveNod_Step();
	}
	else if ((BASIC_TIMER_x8 & u08_TimerCounter_BASEx5) != 0)
	{
		/* 200ms : 5x5x8 ms */
		Run_MirrTintgMgr_Step();
		Run_DstBkpInBody_Step();
		Run_HdlmpMon_Step();
	}
	else
	{
		/*to avoid misra warning*/
	}

    /* check for counter reset */
    if (0xFF == u08_TimerCounter_BASEx5)
    {
        u08_TimerCounter_BASEx5 = 0;
    }
    else
    {
        u08_TimerCounter_BASEx5++;
    }
}//TimerTick_BASEx5

/*****************************************************************************
*
* Name          TimerTick_BASEx25
*
* Author        Josef Hbl
*
* Remark        implements a simulated timer tick
*
*****************************************************************************/

static void TimerTick_BASEx25( void )
{
	static uint08 u08_TimerCounter_BASEx25 = 0;

	if ((BASIC_TIMER_x2 & u08_TimerCounter_BASEx25) != 0)
	{
		/* 250ms : 5x25x2 ms */
		ComCtrl_VIN_Run();
	}
	else if ((BASIC_TIMER_x4 & u08_TimerCounter_BASEx25) != 0)
	{
		/* 500ms : 5x25x4 ms */
		Run_BattMgrPrim_Step();
		Run_PwrSplyChrgnStgy_Step();
		Run_PwrSplyStrtStopMgr_Step();
		Run_EgyMngtModMgr_Step();
		Run_DetnOfUkwnCptMgr_Step();
	}
	else if ((BASIC_TIMER_x8 & u08_TimerCounter_BASEx25) != 0)
	{
		/* 1000ms : 5x25x8 ms */
		Run_CarCfgUknValDet_Step();
		Run_ElAdjSteerColCtrl_Step();
		Run_PwrSplyErrSts_Step();
		Run_BattSwtFuseCtrl_Step();
		Run_FltEgyCns_Step();
		StbM_MainFunction();
		FrTrcv_31_TJA1082_MainFunction();
	}
	else
	{
		/*to avoid misra warning*/
	}

    /* check for counter reset */
    if (0xFF == u08_TimerCounter_BASEx25)
    {
        u08_TimerCounter_BASEx25 = 0;
    }
    else
    {
        u08_TimerCounter_BASEx25++;
    }
}//TimerTick_BASEx25

#endif
